==> contentsquare-0.2.2.tar.gz: test/src/modules/screengraph/screengraph_node_test.dart <==
import 'package:contentsquare/src/modules/screengraph/screengraph_node.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:webview_flutter/webview_flutter.dart';

class MockRootWidget extends StatelessWidget {
  final Widget child;

  const MockRootWidget({Key? key, required this.child}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(child: child);
  }
}

ScreengraphNode getRootElementNode() {
  final rootElement = find.byType(MockRootWidget).first.evaluate().elementAt(0);
  return ScreengraphNode(element: rootElement, path: 'MockRootPath');
}

void main() {
  group('toScreengraphJson', () {
    testWidgets(
        'Should return the JSON formatted Map of the Screengraph node corresponding to the given element',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MockRootWidget(
            child: Text(
          'Hello',
          key: Key('hello_text'),
          textDirection: TextDirection.ltr,
        )),
      );

      final rootNode = getRootElementNode();
      final element =
          find.byKey(const Key('hello_text')).first.evaluate().elementAt(0);
      final node = ScreengraphNode(
        element: element,
        parent: rootNode,
      );

      var generatedScreengraph = await node.toScreengraphJson();

      var expectedScreengraphNodeJson = {
        'id': '[<\'hello_text\'>]',
        'metadata': {
          'class_name': 'Text',
          'fullpath': 'MockRootPath>MockRootWidget>Text',
        },
        'format': 1,
        'recordingId': generatedScreengraph['recordingId'],
        'style': {
          'height': 14.0,
          'width': 70.0,
          'x': 365.0,
          'y': 293.0,
          'visibility': true,
          'bg': '#00FFFFFF',
        }
      };
      expect(await node.toScreengraphJson(), expectedScreengraphNodeJson);
    });

    testWidgets(
        'Should return JSON screengraph with "format": 2 when a webview is present',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MockRootWidget(
            child: WebView(initialUrl: 'https://contentsquare.com/')),
      );

      final rootNode = getRootElementNode();
      final element = find.byType(WebView).first.evaluate().elementAt(0);
      final node = ScreengraphNode(
        element: element,
        parent: rootNode,
      );

      final result = await (node.toScreengraphJson());
      expect(result['metadata']['fullpath'],
          'MockRootPath>MockRootWidget>WebView');
      expect(result['format'], 2);
    });

    testWidgets(
        'Should return a "bmp" field with the widget\'s bitmap if element is a RepaintBoundary',
        (WidgetTester tester) async {
      await tester.pumpWidget(const MaterialApp(
        home: MockRootWidget(
          child: Text(
            'Hello',
            key: Key('hello_text'),
            textDirection: TextDirection.ltr,
          ),
        ),
      ));

      final rootNode = getRootElementNode();
      final element =
          find.byType(RepaintBoundary).first.evaluate().elementAt(0);
      final node = ScreengraphNode(
        element: element,
        parent: rootNode,
      );

      tester.runAsync(() async {
        final result = await (node.toScreengraphJson());
        expect(
          result['style']['bmp'],
          "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",
        );
        expect(result['style']['bg'], null);
      });
    });
    testWidgets(
        'Should return a "bg" field with the default color if element is not a RepaintBoundary',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MockRootWidget(
          child: Text(
            'Hello',
            key: Key('hello_text'),
            textDirection: TextDirection.ltr,
          ),
        ),
      );

      final rootNode = getRootElementNode();
      final element =
          find.byKey(const Key('hello_text')).first.evaluate().elementAt(0);
      final node = ScreengraphNode(
        element: element,
        parent: rootNode,
      );

      final result = await (node.toScreengraphJson());
      expect(result['style']['bmp'], null);
      expect(result['style']['bg'], '#00FFFFFF');
    });
  });
}

==> contentsquare-0.4.2.tar.gz: test/src/modules/screengraph/screengraph_node_test.dart <==
import 'package:contentsquare/src/modules/screengraph/screengraph_node.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:webview_flutter/webview_flutter.dart';

class MockRootWidget extends StatelessWidget {
  final Widget child;

  const MockRootWidget({Key? key, required this.child}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(child: child);
  }
}

ScreengraphNode createRootElementNode({required List<ScreengraphNode> children}) {
  final rootElement = find.byType(MockRootWidget).first.evaluate().elementAt(0);
  return ScreengraphNode(element: rootElement, index: 0, children: children);
}

void main() {
  group('toJson', () {
    testWidgets(
        'Should return the JSON formatted Map of the Screengraph node corresponding to the given element',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MockRootWidget(
            child: Text(
          'Hello',
          key: Key('hello_text'),
          textDirection: TextDirection.ltr,
        )),
      );

      final element =
          find.byKey(const Key('hello_text')).first.evaluate().elementAt(0);
      final node = ScreengraphNode(
        element: element,
        index: 0,
        children: [],
      );
       createRootElementNode(children: [node]);

      var generatedJson = await node.toJson(pixelRatio: 1.0, rootPath: 'MockRootPath');

      var expectedJson = {
        'id': '[<\'hello_text\'>]',
        'metadata': {
          'class_name': 'Text',
          'fullpath': 'MockRootPath>MockRootWidget:eq(0)>Text:eq(0)',
        },
        'recordingId': generatedJson['recordingId'],
        'style': {
          'height': 14.0,
          'width': 70.0,
          'x': 365.0,
          'y': 293.0,
          'visibility': true,
          'bg': '#00FFFFFF',
        },
        'format': 1,
        'children': []
      };
      expect(await node.toJson(pixelRatio: 1.0, rootPath: 'MockRootPath'),
          expectedJson);
    });

    testWidgets(
        'Should return JSON with "format": 2 when a webview is present',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MockRootWidget(
            child: WebView(initialUrl: 'https://contentsquare.com/')),
      );

      final element = find.byType(WebView).first.evaluate().elementAt(0);
      final node = ScreengraphNode(
        element: element,
        index: 0,
        children: []
      );
      createRootElementNode(children: [node]);

      final result = await (node.toJson(pixelRatio: 1.0, rootPath: 'MockRootPath'));
      expect(result['metadata']['fullpath'],
          'MockRootPath>MockRootWidget:eq(0)>WebView:eq(0)');
      expect(result['format'], 2);
    });

    testWidgets(
        'Should return a "bg" field with the default color if element is not a RepaintBoundary',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MockRootWidget(
          child: Text(
            'Hello',
            key: Key('hello_text'),
            textDirection: TextDirection.ltr,
          ),
        ),
      );

      final element =
          find.byKey(const Key('hello_text')).first.evaluate().elementAt(0);
      final node = ScreengraphNode(
        element: element,
        index: 0,
        children: []
      );
      createRootElementNode(children: [node]);

      final result = await (node.toJson(pixelRatio: 1.0, rootPath: 'MockRootPath'));
      expect(result['style']['bmp'], null);
      expect(result['style']['bg'], '#00FFFFFF');
    });
  });
}
